package com.ruoyi.system.controller;

import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;

import com.ruoyi.page.domain.dto.request.EventPageRequest;
import com.ruoyi.page.service.IEventService;
import com.ruoyi.system.domain.Event;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 事故Controller
 *
 * @author ruoyi
 * @date 2024-05-30
 */
@Api(tags = "事故")
@RestController
@RequestMapping("algorithms/event")
public class EventController extends BaseController {
    @Autowired
    private IEventService eventService;

    /**
     * 查询事故列表
     */
    @ApiOperation(value = "查询事故列表", response = Event.class)
    @GetMapping("/list")
    public TableDataInfo list(EventPageRequest req) {
        startPage();
        List<Event> list = eventService.selectEventList(req);
        return getDataTable(list);
    }


    /**
     * 获取事故详细信息
     */
    @ApiOperation(value = "获取事故详细信息", response = Event.class)
    @GetMapping(value = "/{eventId}")
    public AjaxResult getInfo(@PathVariable("eventId") String eventId) {
        return success(eventService.selectEventByEventId(eventId));
    }

    /**
     * 新增事故
     */
    @ApiOperation(value = "新增事故")
    @PostMapping
    public AjaxResult add(@RequestBody Event event) {
        return toAjax(eventService.insertEvent(event));
    }

    /**
     * 修改事故
     */
    @ApiOperation(value = "修改事故")
    @PutMapping
    public AjaxResult edit(@RequestBody Event event) {
        return toAjax(eventService.updateEvent(event));
    }

    /**
     * 删除事故
     */
    @ApiOperation(value = "删除事故")
    @DeleteMapping("/{eventIds}")
    public AjaxResult remove(@PathVariable String[] eventIds) {
        return toAjax(eventService.deleteEventByEventIds(eventIds));
    }
}
